'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Create = require('./blueprints/Create');

var _Create2 = _interopRequireDefault(_Create);

var _Update = require('./blueprints/Update');

var _Update2 = _interopRequireDefault(_Update);

var _Destroy = require('./blueprints/Destroy');

var _Destroy2 = _interopRequireDefault(_Destroy);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getCreateDialog(defaults) {
  return function (props, options) {
    var params = _lodash2.default.assign(defaults, options);
    return _react2.default.createElement((0, _Create2.default)(params), props);
  };
}

function getUpdateDialog(defaults) {
  return function (props, options) {
    var params = _lodash2.default.assign(defaults, options);
    return _react2.default.createElement((0, _Update2.default)(params), props);
  };
}

function getDestroyDialog(defaults) {
  return function (props, options) {
    var params = _lodash2.default.assign(defaults, options);
    return _react2.default.createElement((0, _Destroy2.default)(params), props);
  };
}

exports.default = {

  dependencies: ['models'],

  load: function load(lore) {
    var schemas = lore.loader.loadModels();

    lore.dialogs = {};

    _lodash2.default.mapKeys(schemas, function (schema, modelName) {
      lore.dialogs[modelName] = lore.dialogs[modelName] || {};

      lore.dialogs[modelName].create = getCreateDialog({
        modelName: modelName,
        attributes: schema.attributes,
        title: 'Create ' + _lodash2.default.capitalize(modelName),
        cancelButtonText: 'Cancel',
        submitButtonText: 'Create',
        defaults: {}
      });

      lore.dialogs[modelName].update = getUpdateDialog({
        modelName: modelName,
        attributes: schema.attributes,
        title: 'Update ' + _lodash2.default.capitalize(modelName),
        cancelButtonText: 'Cancel',
        submitButtonText: 'Update',
        defaults: {}
      });

      lore.dialogs[modelName].destroy = getDestroyDialog({
        modelName: modelName,
        attributes: schema.attributes,
        title: 'Delete ' + _lodash2.default.capitalize(modelName),
        cancelButtonText: 'Cancel',
        submitButtonText: 'Delete',
        defaults: {}
      });
    });
  }

};
module.exports = exports['default'];